/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

// Autogenerated by Thrift Compiler (0.14.1-yarped)
//
// This is an automatically generated file.
// It could get re-generated if the ALLOW_IDL_GENERATION flag is on.

#ifndef YARP_THRIFT_GENERATOR_COMMON_DEMO_H
#define YARP_THRIFT_GENERATOR_COMMON_DEMO_H

#include <yarp/test/PointD.h>

namespace yarp {
namespace test {

typedef yarp::test::PointD Point3D;
constexpr std::int32_t ANSWER = 42;

} // namespace yarp
} // namespace test

#endif // YARP_THRIFT_GENERATOR_COMMON_DEMO_H
