/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * Copyright (C) 2006-2010 RobotCub Consortium
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#ifndef YARP_DEV_AUDIOGRABBERINTERFACES_H
#define YARP_DEV_AUDIOGRABBERINTERFACES_H

#include <yarp/dev/AudioGrabberVocabs.h>
#include <yarp/dev/IAudioGrabberSound.h>
#include <yarp/dev/IAudioRender.h>

#endif // YARP_DEV_AUDIOGRABBERINTERFACES_H
