/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef YSCOPEWINDOW_H
#define YSCOPEWINDOW_H

#include <QDialog>

namespace Ui {
class YscopeWindow;
}

class YscopeWindow : public QDialog
{
    Q_OBJECT

public:
    explicit YscopeWindow(QWidget *parent = 0);
    ~YscopeWindow();
    int getIndex();

private:
    Ui::YscopeWindow *ui;
    int index;

private slots:
    void onInspect();
    void onCancel();
    void onIndexChanged(int);
};

#endif // YSCOPEWINDOW_H
