/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#ifndef YARPROBOT_H
#define YARPROBOT_H

int yarp_robot_main(int argc, char *argv[]);
void yarp_robot_help();

#endif
