/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#include <iostream>

int main(int argc, char *argv[]) {
    std::cerr << argv[0] << " is deprecated. Please use \"yarpserver\" instead." << std::endl;
    return 1;
}
