/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#ifndef YARP_OS_NETUINT8_H
#define YARP_OS_NETUINT8_H

namespace yarp {
namespace os {

/**
 * Definition of the NetUint8 type
 */
typedef std::uint8_t NetUint8;

} // namespace os
} // namespace yarp

#endif // YARP_OS_NETUINT8_H
