/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#ifndef YARP_DEV_PRECISELYTIMED_H
#define YARP_DEV_PRECISELYTIMED_H

#include <yarp/conf/system.h>

YARP_COMPILER_WARNING("<yarp/dev/PreciselyTimed.h> file is deprecated. Use <yarp/dev/IPreciselyTimed.h> instead")
#include <yarp/dev/IPreciselyTimed.h>

#endif // YARP_DEV_PRECISELYTIMED_H
