/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

// This is an automatically generated file.

#ifndef YARP_ROSMSG_deprecated2_nav_msgs_Odometry_h
#define YARP_ROSMSG_deprecated2_nav_msgs_Odometry_h

#include <yarp/conf/system.h>

YARP_COMPILER_DEPRECATED_WARNING(<nav_msgs/Odometry.h> header is deprecated. Use <yarp/rosmsg/nav_msgs/Odometry.h> instead)

#include <yarp/rosmsg/nav_msgs/Odometry.h>
#include <nav_msgs_Odometry.h>
#include <yarp/conf/api.h>

namespace nav_msgs {

YARP_DEPRECATED typedef yarp::rosmsg::nav_msgs::Odometry Odometry;

} // namespace nav_msgs

#endif // YARP_ROSMSG_deprecated2_nav_msgs_Odometry_h
