/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#include <yarp/conf/system.h>

YARP_COMPILER_DEPRECATED_WARNING(<yarp/sig/IplImage.h> header is deprecated. Use OpenCV header instead) // Since YARP 3.0.0

// For compatibility with old code
#include <yarp/sig/impl/IplImage.h>
