/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

// This is an automatically generated file.

#ifndef YARP_ROSMSG_deprecated1_visualization_msgs_InteractiveMarkerFeedback_h
#define YARP_ROSMSG_deprecated1_visualization_msgs_InteractiveMarkerFeedback_h

#include <yarp/conf/system.h>

YARP_COMPILER_DEPRECATED_WARNING(<visualization_msgs_InteractiveMarkerFeedback.h> header is deprecated. Use <yarp/rosmsg/visualization_msgs/InteractiveMarkerFeedback.h> instead)

#include <yarp/rosmsg/visualization_msgs/InteractiveMarkerFeedback.h>
#include <std_msgs_Header.h>
#include <geometry_msgs_Pose.h>
#include <geometry_msgs_Point.h>
#include <yarp/conf/api.h>

YARP_DEPRECATED_MSG("visualization_msgs_InteractiveMarkerFeedback is deprecated, use yarp::rosmsg::visualization_msgs::InteractiveMarkerFeedback instead")
typedef yarp::rosmsg::visualization_msgs::InteractiveMarkerFeedback visualization_msgs_InteractiveMarkerFeedback;

#endif // YARP_ROSMSG_deprecated1_visualization_msgs_InteractiveMarkerFeedback_h
