/*
 * Copyright (C) 2006-2021 Istituto Italiano di Tecnologia (IIT)
 * All rights reserved.
 *
 * This software may be modified and distributed under the terms of the
 * BSD-3-Clause license. See the accompanying LICENSE file for details.
 */

#ifndef YARP2_name_ALL
#define YARP2_name_ALL

#include <yarp/name/NameService.h>
#include <yarp/name/NameServerConnectionHandler.h>
#include <yarp/name/NameServerManager.h>
#include <yarp/name/BootstrapServer.h>

#endif
