/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#pragma once

#define TTRANSPORT_CHECK_THROW(_CALL, _TYPE)                                                       \
  {                                                                                                \
    bool caught = false;                                                                           \
    try {                                                                                          \
      (_CALL);                                                                                     \
    } catch (TTransportException & ex) {                                                           \
      BOOST_CHECK_EQUAL(ex.getType(), _TYPE);                                                      \
      caught = true;                                                                               \
    }                                                                                              \
    BOOST_CHECK_MESSAGE(caught, "expected TTransportException but nothing was thrown");            \
  }

#define TTRANSPORT_REQUIRE_THROW(_CALL, _TYPE)                                                     \
  {                                                                                                \
    bool caught = false;                                                                           \
    try {                                                                                          \
      (_CALL);                                                                                     \
    } catch (TTransportException & ex) {                                                           \
      BOOST_REQUIRE_EQUAL(ex.getType(), _TYPE);                                                    \
      caught = true;                                                                               \
    }                                                                                              \
    BOOST_REQUIRE_MESSAGE(caught, "expected TTransportException but nothing was thrown");          \
  }
